/**
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.base.bl.repository;

import java.io.File;

import com.btc.ep.base.bl.Profile;

/**
 * This class defines the repository interface for a profile. A profile is
 * the domain object visible to the user that is saved and loaded to/from a
 * file.
 * 
 * TODO: StHa: Simplify interface ?!
 */
public interface ProfileRepository {

    /**
     * Find a Profile
     * 
     * @return The first Profile in the DataBase. Normally it exist exact one Profile in the DataBase. If no profile
     *         found it return NULL.
     */
    public Profile findProfile();

    /**
     * Adds a Profile to the data repository if it not exist yet (add also all new Elements in the object graph).
     * <p><b>ATTATTION:</b> The update detach the Profile!</p>
     *
     * @param currentProfile The Profile to be updated, must not be null.
     * @return The new attached Profile. [Now all changes on the Profile will be observe automatically by the Provider.
     *         That means,
     *         that all modifications on the Profile will be stored in the Database at next save.
     */
    public Profile updateProfile(Profile currentProfile);

    /**
     * Delete existing Profile and also all persisted Objects.
     */
    public void clearProfile();

    /**
     * Create an backup of the current DataBase.
     *
     * @param sf Destination File for the backup
     * @throws Exception If the file can't access. (e.g. File does not exist.)
     */
    public void backup(File sf) throws Exception;

    /**
     * 
     * Open an existing EPP Profile file.
     * The current Profile will be overwritten by the new without saving of modifications.
     *
     * @param pfile Existing EPP Profile file
     * @throws Exception If the file can't access. (e.g. File does not exist.)
     */
    public void open(File pfile) throws Exception;

    /**
     * FIXME @StHa: What will make this method?
     * Missed Description
     * 
     * @deprecated mehtod do nothing.
     */
    public void closeProfile();
}
