/**
 *  Copyright (c) 2014, 
 *  BTC Embedded Systems AG, Oldenburg, Germany  
 *  All rights reserved
 *  --------------------------------------------------------- 
 *  $Author: $
 *  $Date:  $
 *  $Revision: $
 **/

package com.btc.ep.base.dal.internal;

import java.io.File;
import java.util.Collection;

import com.btc.ep.base.bl.Profile;
import com.btc.ep.base.bl.impl.ProfileImpl;
import com.btc.ep.base.bl.repository.ProfileRepository;
import com.btc.ep.base.dal.impl.BaseRepository;
import com.btc.ep.dal.persist.PersistenceManager;

/**
 * This class is the Repository for Profiles
 * 
 * @author Simon Kollmann
 */

public class ProfileRepositoryImpl implements ProfileRepository {

    /**
     * Injected by OSGi.
     */
    private PersistenceManager persistenceManager;

    private BaseRepository<Profile> baseRepository;

    /**
     * Set the PersistenceManager
     *
     * @param persistenceManager The PersistenceManager
     */
    public void setPersistenceManager(PersistenceManager persistenceManager) {
        this.persistenceManager = persistenceManager;
    }

    /**
     * Set the BaseRepository
     *
     * @param baseRepository The BaseRepository
     */
    public void setBaseRepository(BaseRepository<Profile> baseRepository) {
        this.baseRepository = baseRepository;
    }

    @Override
    public Profile findProfile() {
        Collection<ProfileImpl> profiles = baseRepository.findAll(ProfileImpl.class);

        if (profiles != null && !profiles.isEmpty()) {
            return profiles.iterator().next();
        }
        return null;
    }
    
    @Override
    public Profile updateProfile(Profile currentProfile) {
        return baseRepository.update(currentProfile);
    }

    @Override
    public void clearProfile() {
        baseRepository.clearDatabase();
        persistenceManager.clear();
    }
    
    @Override
    public void backup(File sf) throws Exception {
        persistenceManager.backup(sf);
    }

    @Override
    public void open(File pfile) throws Exception {
        persistenceManager.open(pfile);
    }

    @Override
    public void closeProfile() {
        persistenceManager.close();
        persistenceManager.clear();
    }
}
